Number of the arm that the next subject is assigned to.
Arguments
x.df
A data frame of two columns: treatment arm and response value.
treatment arm.
urn_comp
A vector of current urn composition.
arms
A vector of arm names. If it is not provided, the arms occurred
in x.df will be assumed as all possible arms. Suggest to always assign arms.
group_allo
An integer of the size of group allocation. The default is
1.
add_rule_index
Supply a number of 1 or 2 indicting the
addition rules to target allocation functions.
1 = the SEU model targeting Neyman allocation;
2 = the SEU model that assigns probability of 0.6+1/K to winner at each step.
The default is 1.
add_rule
Supply a user-specified addition rules function of x.df and
arms when add_rule_index is NULL. Default is NULL.
Details
'SEU_GAUSSIAN' assigns the next subject to a group given the observed
success rates, enrolled subjects and allocation function.