Number of the arm that the next subject is assigned to.
Arguments
X.df
A data frame of two columns: treatment arm and response value.
group_allo
An integer of the size of group allocation. The default is
1.
rho_func_index
Supply a number of 1, 2 or 3 indicting the
allocation function to use. (TODO: add reference)
1 = Zhang-Rosenberger allocation;
2 = Neyman allocation.
The default is 2.
rho_func
Supply a user-specified allocation function of Mean_RK and
SD_RK when rho_func_index is NULL. Default is NULL.
alpha
Supply a number indicating the subscripts of the probability
function. The default is 2. huAsymptoticPropertiesDoubly2004RARfreq
Details
'DBCD_GAUSSIAN' assigns the next subject to a group given the observed
success rates, enrolled subjects and allocation function.